@@ -10,7 +10,7 @@ getnetest <- function(dissample,
                       short = FALSE,
                       theta0 = -0.79,
                       parallel = 0,
-                      parallel.type = "MPI",
+                      parallel.type = "PSOCK",
                       Qstart = NULL,
                       MPLEsamplesize = 50000,
                       SAN.nsteps = 2^19,
@@ -502,7 +502,7 @@ oneiteration <- function(sampleTab,
                          SAN.nsteps = 2^19,
                          interval = 10000,
                          parallel = 0,
-                         parallel.type = "MPI",
+                         parallel.type = "PSOCK",
                          crossStat = NULL,
                          rawCounts = NULL,
                          net = NULL,
@@ -765,7 +765,7 @@ fitnet.RDS <- function(target.stats,
                        initialNet,
                        short = FALSE,
                        parallel = 0,
-                       parallel.type = "MPI",
+                       parallel.type = "PSOCK",
                        MPLEsamplesize = 50000,
                        SAN.maxit = 3,
                        SAN.nsteps = 2^19,
